function dy = dglspline(t,y,flag,u,parameter)
% Loesung eines Optimalsteuerungsproblems
% kubisches Spline-Problem 
%
% In diesem File werden die Differentialgleichungen fuer den Integrationsschritt
% definiert.
% -------------------------------------------------------------------------------
% Eingabe - Parameter:
% t : unabhaengige Variable (Zeit)
% y : abhaengige Variable
% flag : wird in diesem Fall nicht benutzt. Mittels "flag" kann die Ausgabe der 
%        Funktion an den Integrator gesteuert werden.
% u : Parameter: Steuerung, diese ist zwischen zwei Knoten konstant.
% parameter: nicht benutzt
% -------------------------------------------------------------------------------
% Rueckgabe-Parameter:
% dy : die rechte Seite der Differentialgleichung y' = f(t,y)
% -------------------------------------------------------------------------------
%
% 11.1.1999   Helge Baumann
%

dy = zeros(3,1);  % erzeugt einen Spaltenvektor mit lauter Nullen.
dy(1) = y(2);
dy(2) = u;
dy(3) = u^2;
return

